==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/componentlibrary/impl/ImportedProvisionInSatisfactionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfaction;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.SatisfactionSetImpl;

import java.util.Arrays;
import java.util.List;


public class ImportedProvisionInSatisfactionSetImpl extends InstanceSet<ImportedProvisionInSatisfactionSet,ImportedProvisionInSatisfaction> implements ImportedProvisionInSatisfactionSet {

    // attributes
    @Override
    public void setSatisfaction_Id( UniqueId ref_Satisfaction_Id ) throws XtumlException {
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisioninsatisfaction.setSatisfaction_Id( ref_Satisfaction_Id );
    }
    @Override
    public void setImportedProvision_Id( UniqueId ref_ImportedProvision_Id ) throws XtumlException {
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisioninsatisfaction.setImportedProvision_Id( ref_ImportedProvision_Id );
    }


    // selections
    @Override
    public SatisfactionSet R4705_provides_satisfaction_through_Satisfaction() throws XtumlException {
        SatisfactionSet satisfactionset = new SatisfactionSetImpl();
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) satisfactionset.add( importedprovisioninsatisfaction.R4705_provides_satisfaction_through_Satisfaction() );
        return satisfactionset;
    }
    @Override
    public ImportedProvisionSet R4705_satisfaction_made_with_ImportedProvision() throws XtumlException {
        ImportedProvisionSet importedprovisionset = new ImportedProvisionSetImpl();
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisionset.add( importedprovisioninsatisfaction.R4705_satisfaction_made_with_ImportedProvision() );
        return importedprovisionset;
    }


    @Override
    public ImportedProvisionInSatisfaction nullElement() {
        return ImportedProvisionInSatisfactionImpl.EMPTY_IMPORTEDPROVISIONINSATISFACTION;
    }

    @Override
    public ImportedProvisionInSatisfactionSet emptySet() {
      return new ImportedProvisionInSatisfactionSetImpl();
    }

    @Override
    public ImportedProvisionInSatisfactionSet value() {
        return this;
    }

    @Override
    public List<ImportedProvisionInSatisfaction> elements() {
        return Arrays.asList(toArray(new ImportedProvisionInSatisfaction[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/componentlibrary/impl/ImportedProvisionInSatisfactionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.SatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfaction;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionInSatisfactionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.ImportedProvisionSet;
import io.ciera.tool.sql.ooaofooa.component.componentlibrary.impl.ImportedProvisionSetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.SatisfactionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ImportedProvisionInSatisfactionSetImpl extends InstanceSet<ImportedProvisionInSatisfactionSet,ImportedProvisionInSatisfaction> implements ImportedProvisionInSatisfactionSet {

    public ImportedProvisionInSatisfactionSetImpl() {
    }

    public ImportedProvisionInSatisfactionSetImpl(Comparator<? super ImportedProvisionInSatisfaction> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSatisfaction_Id( UniqueId ref_Satisfaction_Id ) throws XtumlException {
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisioninsatisfaction.setSatisfaction_Id( ref_Satisfaction_Id );
    }
    @Override
    public void setImportedProvision_Id( UniqueId ref_ImportedProvision_Id ) throws XtumlException {
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisioninsatisfaction.setImportedProvision_Id( ref_ImportedProvision_Id );
    }


    // selections
    @Override
    public SatisfactionSet R4705_provides_satisfaction_through_Satisfaction() throws XtumlException {
        SatisfactionSet satisfactionset = new SatisfactionSetImpl();
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) satisfactionset.add( importedprovisioninsatisfaction.R4705_provides_satisfaction_through_Satisfaction() );
        return satisfactionset;
    }
    @Override
    public ImportedProvisionSet R4705_satisfaction_made_with_ImportedProvision() throws XtumlException {
        ImportedProvisionSet importedprovisionset = new ImportedProvisionSetImpl();
        for ( ImportedProvisionInSatisfaction importedprovisioninsatisfaction : this ) importedprovisionset.add( importedprovisioninsatisfaction.R4705_satisfaction_made_with_ImportedProvision() );
        return importedprovisionset;
    }


    @Override
    public ImportedProvisionInSatisfaction nullElement() {
        return ImportedProvisionInSatisfactionImpl.EMPTY_IMPORTEDPROVISIONINSATISFACTION;
    }

    @Override
    public ImportedProvisionInSatisfactionSet emptySet() {
      return new ImportedProvisionInSatisfactionSetImpl();
    }

    @Override
    public ImportedProvisionInSatisfactionSet emptySet(Comparator<? super ImportedProvisionInSatisfaction> comp) {
      return new ImportedProvisionInSatisfactionSetImpl(comp);
    }

    @Override
    public ImportedProvisionInSatisfactionSet value() {
        return this;
    }

    @Override
    public List<ImportedProvisionInSatisfaction> elements() {
        return Arrays.asList(toArray(new ImportedProvisionInSatisfaction[0]));
    }

}
